from astropy.utils.data import REMOTE_TIMEOUT

REMOTE_TIMEOUT.set(10.)
import bandpasses
import sources
import magsystems
